Package: cageminer
Title: Candidate Gene Miner
Version: 1.18.0
Authors@R: 
    c(
    person(given = "Fabrício",
           family = "Almeida-Silva",
           role = c("aut", "cre"),
           email = "fabricio_almeidasilva@hotmail.com",
           comment = c(ORCID = "0000-0002-5314-2964")),
    person(given = "Thiago",
           family = "Venancio",
           role = "aut",
           comment = c(ORCID = "0000-0002-2215-8082"))
    )
Description: This package aims to integrate GWAS-derived SNPs and coexpression
    networks to mine candidate genes associated with a particular phenotype.
    For that, users must define a set of guide genes, which are known genes 
    involved in the studied phenotype. Additionally, the mined candidates can
    be given a score that favor candidates that are hubs and/or transcription
    factors. The scores can then be used to rank and select the top n most
    promising genes for downstream experiments.
License: GPL-3
URL: https://github.com/almeidasilvaf/cageminer
BugReports: https://support.bioconductor.org/t/cageminer
biocViews: Software, SNP, FunctionalPrediction, GenomeWideAssociation,
        GeneExpression, NetworkEnrichment, VariantAnnotation,
        FunctionalGenomics, Network
Encoding: UTF-8
LazyData: false
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Imports: ggplot2, rlang, ggbio, ggtext, GenomeInfoDb, GenomicRanges,
        IRanges, reshape2, methods, BioNERO
Depends: R (>= 4.1)
Suggests: testthat (>= 3.0.0), SummarizedExperiment, knitr, BiocStyle,
        rmarkdown, covr, sessioninfo
Config/testthat/edition: 3
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/cageminer
git_branch: RELEASE_3_23
git_last_commit: 2f4c34c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:02:55 UTC; biocbuild
Author: Fabrício Almeida-Silva [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5314-2964>),
  Thiago Venancio [aut] (ORCID: <https://orcid.org/0000-0002-2215-8082>)
Maintainer: Fabrício Almeida-Silva <fabricio_almeidasilva@hotmail.com>
