# Generated by roxygen2: do not edit by hand

export(mine_candidates)
export(mine_step1)
export(mine_step2)
export(mine_step3)
export(plot_snp_circos)
export(plot_snp_distribution)
export(score_genes)
export(simulate_windows)
importFrom(BioNERO,gene_significance)
importFrom(BioNERO,module_enrichment)
importFrom(GenomeInfoDb,keepSeqlevels)
importFrom(GenomeInfoDb,seqinfo)
importFrom(GenomeInfoDb,seqlengths)
importFrom(GenomeInfoDb,seqlevels)
importFrom(GenomicRanges,GRangesList)
importFrom(GenomicRanges,countOverlaps)
importFrom(GenomicRanges,end)
importFrom(GenomicRanges,mcols)
importFrom(GenomicRanges,tileGenome)
importFrom(GenomicRanges,width)
importFrom(IRanges,subsetByOverlaps)
importFrom(ggbio,circle)
importFrom(ggbio,ggbio)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggtext,element_textbox_simple)
importFrom(methods,is)
importFrom(reshape2,melt)
importFrom(rlang,.data)
